2024-01-19 Version: 1.3.0
- Generated python2 2023-06-01 for bailian.

2024-01-05 Version: 1.2.0
- Generated python2 2023-06-01 for bailian.

2023-12-14 Version: 1.1.0
- Generated python2 2023-06-01 for bailian.

2023-11-08 Version: 1.0.0
- Generated python2 2023-06-01 for bailian.

